@@ -1,4 +1,4 @@
-from request import Client
+from ofxclient.client import Client
 from StringIO import StringIO
 
 def combined_download(accounts,days=60):
